package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````("8``#0```!@L@```````#0`(``,
M`"@`'@`=``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````&!4`
M`!@5```$`````!````$`````(````"`````@``"(-```B#0```4`````$```
M`0````!@````8````&```+A-``"X30``!``````0```!````N*X``+B^``"X
MO@``2`(``(@2```&`````!````(```#`K@``P+X``,"^```0`0``$`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1<G@``7)X``%R>```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DN*X``+B^``"XO@``2`$``$@!```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`*L(ZD,%_G''?9!_MW8-&54G-HDJ!```
M`!@````%````1TY5``$``<`$`````0````(``<`$``````````0````0````
M`0```$=.50```````P````(`````````80```&,``````````````%$````^
M```````````````%```````````````T````.@````````!&`````@```%P`
M````````+0```$D```!*````'@```%<```!@`````P```$,`````````````
M`"8```!3````0@``````````````2P```$0```!0``````````````!B````
M(0`````````(`````````!D`````````%0```%@```!(````-0````````!%
M````6@```#8````.````-P``````````````4@```#(````]````00``````
M```````````````````_`````````````````````````!@````L````````
M`"X````E````,```````````````60```!8````Y````/````$P````X````
M,0`````````[````````````````````6P```$T`````````0````$\````)
M````'````"0````!````````````````````````````````````!```````
M``````````````````````````````````!>````````````````````#P``
M`%\``````````````$X`````````````````````````%P``````````````
M"@```!T`````````70`````````3````'P```&$`````````````````````
M````&@`````````1`````````"(````&````*@```"`````,`````````!0`
M```K````````````````````1P`````````+````)P````T`````````&P``
M```````O````$````"@```!4````````````````````````````````````
M!P```#,````````````````````2```````````````C````*0``````````
M``````````````````````````````!5`````````````````````````%8`
M````````$0```$<````(````"``````0$`0E0`2`*`$`!:"&`(2``0``"R@$
M"#B@$D6*```(`````$<```!*````30```$X```!5````5@```%<```!9````
M6@```%P```!=````7P```&````!B``````````````!NQ=\?SMY'+6M_FGPN
MQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^Z%L8&L)
M0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-XYX5C"7,##J7"UGH[>Q_J9R;X*<"
M"FL:GE"CX/M)`````````````````````&D"`````````````!(```!:`0``
M```````````2````8P(`````````````$@````P"`````````````!(```"Y
M`@`````````````2````Y@``````````````$0```(0!`````````````!(`
M``#S`0`````````````2````CP(`````````````$@```($"````````````
M`!(```"O`0`````````````2````'0``````````````(````%(!````````
M`````!(```!H`0`````````````2````=@``````````````$@```#X"````
M`````````!(```"I`@`````````````2````/`$`````````````$@```&0`
M`````````````!(```#F`@`````````````2````G@(`````````````$@``
M``$``````````````"`````D`@`````````````2````$0(`````````````
M$@```*(``````````````!(````L```````````````@````FP``````````
M````$@```*D``````````````!(````6`@`````````````2````\0``````
M````````$@```,(!`````````````!(````,`0`````````````2````+P(`
M````````````$@```+$``````````````!(```!Z`@`````````````1````
M80$`````````````$@```+L``````````````!(```#0```````````````2
M````QP,`````````````$@```"T!`````````````!(```"2`0``````````
M```2````B@``````````````$0```-<``````````````!(```"C`@``````
M```````2````_@$`````````````$@```)D!`````````````!(```#L`0``
M```````````2````1P(`````````````$@```-H"`````````````!(```#Z
M`@`````````````2````X```````````````$@```(D``````````````"$`
M``!O`0`````````````2````F@``````````````$@```!T!````````````
M`!(```!*`0`````````````2````Q0(`````````````$@```.`!````````
M`````!(```#"```````````````2````B```````````````$0```"8!````
M`````````!(```"2```````````````2````TP$`````````````$0````$!
M`````````````!(```"@`0`````````````2````?0$`````````````$@``
M`)8"`````````````!(```!V`0`````````````2````50``````````````
M(@```%X"`````````````!(```#0`P``H$0```H!```2`!``)@0``!!)```E
M"```$@`0`'$```#0(P``2`(``!(`$``P`P``X#H```4````2`!``90,``$!1
M``!V`@``$@`0`$P$``#P.@``!0(``!(`$``,!````,$````````0`!L`00,`
M```]```D````$@`0`'L#``"00@``=@```!(`$`!&````!&````0````1`!(`
MZ0,``+!%``"_`0``$@`0`/0#``#0.0``.P```!(`$``A!```0-$````````0
M`!L`.@0``$!#``#U````$@`0`-P#``#PP````````!``&@"?`P``,#T``/4`
M```2`!``,P0```#!````````$``:`%D$``#\P```!````!$`&@!.`P``(%0`
M``$````2`!``X@,``"`F```V````$@`0`/P#``#`4P``70```!(`$``8!```
M0$0``%(````2`!``W@,``/#`````````(``:`%X#````8```!````!$`$@"U
M`P``$$,``"L````2`!``B0,``!`Z``#(````$@`0`*L#``!P1P``H`$``!(`
M$`!C!```,#X``%@$```2`!```%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%])
M3U]S=&1I;E]U<V5D`%]?8WAA7V9I;F%L:7IE`%]?;&EB8U]S=&%R=%]M86EN
M`%]?<F5G:7-T97)?871F;W)K`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`
M86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK
M`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]T:')?:V5Y`&)O;W1?1'EN84QO
M861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`;65M
M8VAR`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`;65M;6]V90!R96%L
M;&]C`&=E='!I9`!M96UC<'D`<W1R8VAR`'-T<G1O:P!S=')C;7``<W1R9'5P
M`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!097)L7W-Y<U]I;FET,P!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U
M;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T<G5C
M=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?8V]N
M<W1R=6-T`'!E<FQ?<G5N`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``97AI=`!M
M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P
M96XV-`!L<V5E:S8T`')E860`8VQO<V4`4&5R;%]G=E]F971C:'!V`%!E<FQ?
M9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`'!T:')E
M861?9V5T<W!E8VEF:6,`7U]S=&%C:U]C:&M?9F%I;`!L:6)P97)L+G-O`&QI
M8G!T:')E860N<V\N,`!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN
M:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`
M<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C``1TQ)0D-?
M,BXQ+C,`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C,S`$=,24)#7S(N
M,RXR`$=,24)#7S(N,0!'3$E"0U\R+C,N-``O=7-R+VQI8B]P97)L-2\U+C,R
M+C$O:34X-BUL:6YU>"UT:')E860M;75L=&DO0T]210````(``@`"````````
M``,````$``,```````(``@`%``````````(`!@`"```````"``(````'``(`
M``````````````@``@`"``(``@`"`````@`"``(``@````(``@``````"0`"
M``(``@`'``(``@```````P`"``(``@`````````"``0``@`*``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$`%@,``!`````@````$&EI#0``!@!P!`````````$`"``F`P``
M$`````````!S'VD)```*`'H$```0````%&EI#0``"0"&!```$````!)I:0T`
M``@`D`0``!````"SD98&```'`)H$```0````<AEI"0``!0"E!```$````!%I
M:0T```0`L00``!````!T&6D)```#`+L$```0````$&EI#0```@!P!```````
M`+B^```(````O+X```@```#\OP``"````/3````(````_,````@```#0OP``
M!@8``-2_```&"P``V+\```8,``#<OP``!A8``."_```&&@``Y+\```8>``#H
MOP``!A\``.R_```&(P``\+\```8J``#TOP``!C\``/B_```&10``#,````<!
M```0P```!P(``!3````'`P``&,````<$```<P```!P4``"#````'!P``),``
M``<(```HP```!PD``"S````'"@``,,````<-```TP```!PX``#C````'#P``
M/,````<0``!`P```!Q$``$3````'$@``2,````<3``!,P```!Q0``%#````'
M%0``5,````<7``!8P```!Q@``%S````'&0``8,````<;``!DP```!QP``&C`
M```''0``;,````<@``!PP```!R$``'3````'(@``>,````<D``!\P```!R4`
M`(#````')@``A,````<G``"(P```!R@``(S````'*0``D,````<K``"4P```
M!RP``)C````'+0``G,````<N``"@P```!R\``*3````',```J,````<Q``"L
MP```!S(``+#````',P``M,````<U``"XP```!S8``+S````'-P``P,````<X
M``#$P```!SD``,C````'.@``S,````<[``#0P```!ST``-3````'/@``V,``
M``=```#<P```!T$``.#````'0@``Y,````=#``#HP```!T0``.S````'1@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z%<&``"!P_>?``"+@]C___^%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S_
M__^C[````&C``0``Z6#\____H_C___]FD```````````C4PD!(/D\/]Q_%6)
MY5>)SU93Z'D"``"!PQF<``!1@^PLBT$$B474BT$(B4709:$4````B47D,<"-
M1=!0C4744%'H6O___XN#U/___X/$#%!0_[/H____Z`0P``"+@_3___^#Q!"`
M.``/A#,!``"+L]#___^#[`S_-NCB_/__@(B>`@```EC_-NC3_/__@\00@(B>
M`@```8L'C5`#@\`$B57,/?___S\/AWT!``"#[`S!X`)0Z)?^__^+==2+/X/$
M$(G!B8,L`0``BP:)`8V#0J'__XE!!(N#_````(E!"(V#1:'__XE!#(/_`0^.
M/@$``(E-R(U&!(U1$(TTOHUV`(L(@\`$@\($B4K\.?!U\8M-R(/'`X/L#(V#
M,';__\<$N0````!J`%'_=<Q0_[,D`0``Z(G[__^#Q"")QH7`#X26````@^P,
M_[,D`0``C7W@Z#O]__^)^HV#IZ#__^@.#@``@\00A<`/A(4```"#[`S_LR0!
M``#H%?O__^A0_/__@\00BT7D92L%%`````^%I@```(UE\(GP65M>7UV-8?S#
MZ-K[__^)@R0!``"%P`^$B@```(/L#%#H,_S__XNST/___UK_-NB5^___@\00
MQH!)!@```.F:_O__@^P,_[,D`0``Z#C[__^#Q!")QNE2____BX,H`0``A<!T
M$8/L#%#HRQX``(/$$.E@____B?J-@UR@___H5@T``(F#*`$``(7`#X1%____
MZ]+HD?S__[\$````Z=S^___H4BX``(/L#&H!Z)C]__]FD&:09I!FD#'M7HGA
M@^3P4%12Z"(```"!P]"9``"-@R"4__]0C8/`D___4%%6_[/\____Z,_Z___T
MBQPDPV:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.````"!PHN9``"-B@`!
M``"-@@`!```YR'0=BX+<____A<!T$U6)Y8/L%%'_T(/$$,G#C70F`)##C;0F
M`````.B@````@<)+F0``58GE4XV*``$``(V"``$``(/L!"G(B</!Z!_!^P(!
MV-'X=!2+DN#___^%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:058GE4^A7
M____@</WF```@^P$@+L``0```'4GBX/X____A<!T$8/L#/^S]````.B-_/__
M@\00Z#7____&@P`!```!BUW\R<.-M"8`````9I#I6____XL4),-FD&:09I"0
M55=64XG#@>Q\`0``B40D#(U4)"QEH10```")A"1L`0``,<"-="8`D(M,@QP/
MR8D,@H/``8/X$'7OC8PD+`$``(M"-#-"((/"!#-"!#-"_-'`B4(\.<IUZ(M\
M)`R+1"0LBS>+5Q"+;PB+3PR)5"0<C90"F7F"6HGPBU\$P<`%B4PD"(GW`<*)
MZ(E<)!0QR(E\)!`AV(EL)!@QR(G9BUPD,`'"P<D"B>@QR"'PBW0D"#'HC;0>
MF7F"6HM<)#0!QHG0P<`%C9P=F7F"6HML)#@!QHGXP<@"B<>)R#'X(=#!R@(Q
MR(V,*9EY@EH!PXGPP<`%`<.)^#'0B=TA\,'%!3'XP<X"`<@!Z(G5,?6)Z8ML
M)#PAV3'1C;POF7F"6HG%`?G!Q04!Z<'+`HGU,=V)[XML)$`AQ\'(`C'WC90J
MF7F"6HG-`?K!Q06)QXG8`>HQ^(ML)$0AR#'8C;0NF7F"6HG]`?")UL'&!0'P
MB<[!S@(Q]8GIBVPD2"'1,?F-G"N9>8):BVPD3`'9B</!PP6-O"^9>8):`=F)
MTXGRP<L"B<TQVL'%!2'"P<@",?(!^HG'B=@!ZC'XBVPD4"'(,=B-M"Z9>8):
MB?T!\(G6P<8%`?")SL'.`C'UB>F+;"14(=$Q^8V<*YEY@EJ+;"18`=F)P\'#
M!8V\+YEY@EH!V8G3B?+!RP*)S3':P<4%(<+!R`(Q\@'ZB<>)V`'J,?B+;"1<
M(<@QV(VT+IEY@EJ)_0'PB=;!Q@4!\(G.P<X",?6)Z8ML)&`AT3'YC9PKF7F"
M6HML)&0!V8G#P<,%C;POF7F"6@'9B=.)\L'+`HG-,=K!Q04APL'(`C'R`?J+
M?"1H`>J)Q8G8,>B-M#Z9>8):BWPD;"'(P<D",=B-O#N9>8):`?")UL'&!0'P
MB>XQSHG#(=;!PP4Q[L'*`@'WBW0D<`'?B<LQTXVT-9EY@EJ+;"1T(</!R`(Q
MRXV,*9EY@EH!WHG[P<,%`=Z)TS'#B?4A^S'3P<4%`<O!SP(!ZXG%,?V)Z8ML
M)'@A\<'.`C'!C90JF7F"6@'1B=K!P@4!T8M4)'R-A!"AZ]ENB?HQ\C':P<L"
M`<*)R,'`!0'"BX0D@````(G5C;P'H>O9;HGPP<4%,=@QR`'X`>B)S8N,)(0`
M``#!S0*)[XG=C;0.H>O9;C']B>DQT0'QB<;!Q@4!\8G6BY0DB````,'.`HV<
M$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```")U8V\!Z'KV6Z)\,'%
M!3'8,<@!^`'HB<V+C"20````P<T"B>^)W8VT#J'KV6XQ_8GI,=$!\8G&P<8%
M`?&)UHN4))0```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"28
M````B=6-O`>AZ]ENB?#!Q04QV#'(`?@!Z(G-BXPDG````,'-`HGOB=V-M`ZA
MZ]EN,?V)Z3'1`?&)QL'&!0'QB=:+E"2@````P<X"C9P3H>O9;HGZ,?(QPL'(
M`@':B<O!PP4!VHG#BX0DI````(G5C;P'H>O9;HGPP<4%,=@QR`'X`>B)S8N,
M)*@```#!S0*)[XG=C;0.H>O9;C']B>DQT0'QB<;!Q@4!\8G6BY0DK````,'.
M`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````")U8V\!Z'KV6Z)
M\,'%!3'8,<@!^`'HB<V+C"2T````P<T"B>^)W8VT#J'KV6XQ_8GI,=$!\8G&
MP<8%`?&)UHN4)+@```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+
MA"2\````B=6-O`>AZ]ENB?#!Q04QV#'(`?@!Z(G-BXPDP````,'-`HGOB=V-
MM`ZAZ]EN,?V)Z3'1`?&)QL'&!0'QB=:+E"3$````P<X"C9P3H>O9;HGZ,?(Q
MPL'(`HG%`=J+A"3(````B<O!PP4!VHV<!Z'KV6Z)\#'H,<@!V(G3P<D"P<,%
M`=B)ZPG+B=^)ZR'7(<O!R@()^XN\),P```"-M#[<O!N/`?.)QL'&!0'SB<X)
MUHGWB<XAQR'6P<@""?Z+O"30````C;P]W+P;CP'WB=[!Q@4!]XG6"<:)]8G6
M(=TAQL'+`@GNBZPDU````(V,*=R\&X^)_0'.P<4%B<$![HG=B<,)ZR'I(?L)
MV8N<)-@```"-G!K<O!N/B?(!R\'"!<'/`@'3B>H)^HG1B>HA\2'ZP<X""<J+
MC"3<````C8P(W+P;CXG8`='!P`6)^@'!"?*)^"':(?#!RP()T(N4).````"-
ME!7<O!N/B?4!PHG("=W!P`4AS0'"B?`AV`GHBZPDY````(V\+]R\&X^)U0'X
MP<4%`>B)S8G9P<T"B>^)W0G](?DAU0GIBZPDZ````(VT+MR\&X^)_0'QB<;!
MQ@4!\8G6B?K!S@()]2'R(<7!R`()ZHNL).P```"-G"O<O!N/B?4!VHG+"<7!
MPP4AS0':B<.)\"'8">B+K"3P````C;POW+P;CXG5`?C!Q04!Z(G-B=G!S0*)
M[XG="?TA^2'5">F+K"3T````C;0NW+P;CXG]`?&)QL'&!0'QB=:)^L'.`@GU
M(?(AQ0GJBZPD^````(V<*]R\&X^)]0':B<O!R`+!PP4)Q0':B<.)\"'-(=@)
MZ(NL)/P```"-O"_<O!N/B=4!^,'%!0'HB<V)V<'-`HGOB=T)_2'Y(=4)Z8NL
M)``!``"-M"[<O!N/B?T!\8G&P<8%`?&)UHGZP<X""?4A\B'%P<@"">J+K"0$
M`0``C9PKW+P;CXG%`=J)R\'#!0':B?,)PXGP(<LAZ`G8BYPD"`$``(V<']R\
M&X\!V(G3P<D"P<,%`=B)ZPG+B=^)ZR'7(<O!R@()^XN\)`P!``"-M#[<O!N/
M`?.)QL'&!0'SB<X)UHGWB<XAQR'6P<@""?Z+O"00`0``C;P]W+P;CXG=`?[!
MQ06)UP'NB=4AQPG%(=W!RP()[XNL)!0!``"-C"G<O!N/B?4!^<'%!8G'`>F)
MQ2'?"=TA]0GOBZPD&`$``(V4*MR\&X\!UXG*P<X"P<(%`=>+E"0<`0``C900
MUL%BRHG8,?`QR,')`@'0B?K!P@4!T(N4)"`!``"-G!/6P6+*B?(QRC'ZP<\"
M`=J)P\'#!0':BYPD)`$``(VT'M;!8LJ)RS'[,<,!\XG6P<8%`?.)QHN$)"@!
M``#!S@*)W8V,`=;!8LJ)^,'%!3'P,=#!R@(!R(G1BY0D+`$```'HB?4QS8V4
M%];!8LJ)[S'?`=>)PL'"!0'7BY0D,`$``,'+`HG=C;06UL%BRHG*,=HQP@'R
MB?[!Q@4!\HG&BX0D-`$``,'.`C'UC80!UL%BRHGI,?G!SP(!P8G0P<`%`<&+
MA"0X`0``C9P#UL%BRHGP,?@QT`'8B<O!PP4!V(G3BY0D/`$``,'+`HV4%M;!
M8LJ)_C'>,<[!R0(!UHG"P<(%`=:+E"1``0``B?6-O!?6P6+*B=K!Q04QRC'"
MP<@"`?J)QXN$)$0!```!ZHV$`];!8LJ)RS'[,?/!S@(!PXG0P<`%`<.+A"1(
M`0``B=V-C`'6P6+*B?C!Q04Q\#'0P<H"`<B)T8N4)$P!```!Z(GU,<V-E!?6
MP6+*B>\QW\'+`@'7B<*)W<'"!0'7BY0D4`$``(VT%M;!8LJ)RC':,<(!\HG^
MP<8%`?*)QHN$)%0!``#!S@(Q]8V$`=;!8LJ)Z3'YP<\"`<&)T,'`!0'!BX0D
M6`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)%P!``#!RP*-E!;6P6+*
MB?XQWC'.P<D"`=:)PL'"!0'6BY0D8`$``(GUC;P7UL%BRHG:P<4%,<HQPL'(
M`@'ZB[PD9`$```'JC;P[UL%BRHG+B=4QP\'%!3'SP<X"`?N+O"1H`0```>N+
M;"00C;P]UL%BRHG%,?4!SXGIB=TQT<'%!0'YBWPD#,'*`@'IB0^+3"04`=F)
M3P2+3"0(`U0D&`-$)!R)5PB-%#&)5PR)1Q"+A"1L`0``92L%%````'4+@<1\
M`0``6UY?7</H+"$``(VT)@````"-="8`D%575E/H%_/__X'#MXP``(/L'(E$
M)`2)5"0,A<`/A)X```")P8N#\/___XL`B40D"(7`#X2(````#[8!A,!T!#P]
M=3TQ]HM\)`B++X7M=">0@^P$5O]T)`Q5Z++O__^#Q!"%P'4'@'PU`#UT-(MO
M!(/'!(7M==J#Q!R)Z%M>7UW#B<X/MD8!@\8!A,!T!#P]=?$K="0$ZZZ-M"8`
M````9I"+1"0,B?DK3"0(C6PU`<'Y`HD(@\0<B>A;7E]=PXUV`(/$'#'M6XGH
M7E]=PXUT)@!6B<93Z$?R__^!P^>+``"#['QEH10```")1"1T,<"-1"044%;H
MI^[__X/$$(7`=3B+5"0<@>(`\```@?H`0```=`B!^@"@``!U((/L"&H"5N@+
M[?__@\00A<`/E,`/ML#K"(VV`````#'`BU0D;&4K%10```!U!H/$=%M>P^C.
M'P``C;0F`````(VT)@````!55U:)QE/HM?'__X'#58L``('LC````&6A%```
M`(E$)'PQP(7V=`6`/@!U)(M$)'QE*P44````#X5,`0``@<2,````6UY?7<.-
MM"8`````D(/L#%;HE^S__X/$$(G'A<!TRHV#"*#__XE$)`2-1"0<B40D"(/L
M#%?HL^S__X/$$(7`#X2X````@'@3+HU0$W4/@'H!`'3=C;0F`````&:0@'@3
M+@^$M@```(E4)`R#[`Q6Z)GL__^+5"0<B<6)%"2)5"0<Z(?L__^-1`4"B00D
MZ`OM__^)Q5A:BU0D%%)6_W0D%&K_:@%5Z*/M__^#Q!C_="005>CFZ___@\00
M@_C_=!"+1"0L)0#P```]`$```'1N@^P,5>A%[/__@\00@^P,5>B9Z___@\00
M@^P,5^C]Z___@\00A<`/A4K___]FD(/L#%?H5^S__XDT).C/[/__@\00Z=/^
M__^-M"8`````@'H!+@^%0/___X!Z`@`/A`#____I,?___XVT)@````")Z.AY
M_O__ZY7H,AX``&:05E/H*?#__X'#R8D``(/L$(NST/____\VZ./J__]8_S;H
MV^K__XV34-[__U*-DPZ@____L^3___]24.CQ[/__@\04_S;HM^K__UE>:@")
MPHV#M:'__U!0C8-`D?__4(V#*J#__U!2Z!7K__^#Q"1;7L.-M"8`````C;0F
M`````)!55U93@>P`$```@PPD`(/L,.B:[___@<,ZB0``B50D$(G&9:$4````
MB80D(!```#'`:/\/``"-@S^@__^-;"0D55#H^>O__X/$$(7`?D*`?`0;`(UX
M_W5XA?]T-(/L!%=J+U7H*.S__X/$$(7`="&+@]#___^#[`S_,.@!ZO__5U56
M4.CHZO__@\0@ZR2-=@"+@]#___^#[`S_,.C@Z?__@\0,_W0D$%90Z++I__^#
MQ!"+A"0<$```92L%%````'43@<0L$```6UY?7<.-="8`B<?KB.C7'```C;0F
M`````%6)Q5=6B=93Z,/N__^!PV.(``"#[#AEH10```")1"0H,<`QP(`Z/0^4
MP`'&5N@NZO__@\00B40D!(U4)!B)Z.AL^___A<`/A`0!``"#[`R)QU#H">K_
M_X/$$#E$)`0/ALP```"+1"08P>`"B40D"(N#\/___XD$)`^V10"$P`^$G`$`
M`#P]#X24`0``B>AFD`^V4`&#P`&$TG0%@/H]=?`IZ(L,)(M\)`B#[`R+5"00
M`SF-1!`"4.@TZO__@\00B0>%P'1*BPPDBWPD"(L!C4T!BQ0X#[9%`(@"A,!T
M'3P]=0KK%XUT)@"$P'0/#[8!@\(!@\$!B`(\/77MQ@(],<`/M@P&B$P"`8/`
M`83)=?&+1"0<92L%%`````^%$P$``(/$+%M>7UW#C;0F`````)`QP(VV````
M``^V%`:(%`>#P`&$TG7RZ\>-M"8`````D(N#\/___XL0B00DBSJ%_P^$P@``
M`#'_C;0F`````&:0B?B#QP&+#+J%R77TC02%#````(N+(`$``(7)=6.)5"0,
M@^P,4,>#(`$```$```#H3.G__X/$$(G!A<`/A%[___^-!+T`````@^P$B40D
M#%"+5"044E&)3"0<Z*'I__^+1"00BTPD'(/$$(D(QT2Y!`````")?"08Z8O^
M__^-=@"#[`A04N@VY___B<&+1"00@\00B0B%R0^$`O___XT$O0````")1"0(
MZ\*-M@`````QP.E[_O__N`@````Q_^E0____Z)@:``"-M"8`````D%/HBNS_
M_X'#*H8``(/L%(N#T/____\PZ$3G__^-DU#>__]2C9,.H/___[/D____4E#H
M6NG__X/$*%O#C70F`)!55U93@>P`$```@PPD`('L`!```(,,)`"#[!PQ[>@N
M[/__@</.A0``9:$4````B80D#"```#'`Z/3E__^#[`B-DTJ@__]24(V#3J#_
M_U!H`1```&H!C;0D)Q```%;HONC__X/$'&@`$```C7PD$E=6Z&OH__^#Q!"%
MP'@J@^P,B<:-0`%0Z.;G__^#Q!")Q87`=!.#[`165U#H,N?__\9$-0``@\00
MBX0D#"```&4K!10```!U#8'$'"```(GH6UY?7</HB!D``(VT)@````"0Z2O_
M__^-M"8`````C70F`%575E.![``0``"##"0`@>R<````Z%?K__^!P_>$``"+
MK"2P$```B[PDM!```&6A%````(F$)(P0```QP(U$)"R)1"0(B<*-@UR@___H
M__?__X/L"&HOB<95Z(+E__^#Q!"%P'0SC8-EH/__B>KH+OS__XGHBY0DC!``
M`&4K%10````/A7@!``"!Q)P0``!;7E]=PXUT)@"0@^P,5>A?YO__6EF)1"08
MC8-RH/__B40D(%!7Z"CG__^#Q!")QX7`=*2-DUJ@__^);"0,BVPD&(E4)!R-
MDW2@__^)5"04C78`@#\`#X2_````A?9T%8/L"%=6Z+GG__^#Q!"%P`^$?@``
M`(/L#%?H]>7__X/$$(!\!_\O=1&-=@"#Z`&`?`?_+\8$!P!T\HM,)!"-1`@!
M/?\/``!_8X/L!(V#=:'___]T)!#_="0<5U!H`!```&H!C;PDJ````%?HY.;_
M_X/$&/]T)!!7Z"?E__^#Q!"%P'40BT0D/"4`\```/0"```!T4(/L"%5J`.A5
MYO__@\00B<>%P`^%2/___XML)`SIQ/[__XVT)@````"%]G0%@#XN=`^+?"0<
MN`$```#I9____Y"`?@$`=+KKZ8VT)@````"0@^P(:@%7Z*7D__^#Q!"%P'6>
MB?J-@V6@___HL?K__X/L#%?HF.;__X/$$.ET_O__Z&L7``"-M"8`````C70F
M`(M$)`0/MA")P832=!2-=@"#P`&`^B]U`HG!#[80A-)U[XG(PXVT)@````"-
M="8`D%93Z"GI__^!P\F"``"#[`2+="00A?8/A+0```"`/@`/A*L```"#[`Q6
MZ)+D__^#Q!"-1`;_.<9R#NFN````9I"#Z`$YQG0E@#@O=/0YQ@^#F````(/H
M`3G&=!&-="8`D(`X+W0P@^@!.<9U](`^+W1?@^P,C8-TH/__4.C0Y?__@\00
M@\0$B<*)T%M>PXUV`(`X+W4'@^@!.<9R]"GP,=*-2`*!^0`0``!W&X/``6@`
M$```4%:-LT`!``!6Z(_B__^#Q!")\H/$!(G06U[#9I"#[`R-@UJ@__]0Z''E
M__^#Q!"#Q`2)PHG06U[#.<9UI>EW____C;0F`````(UT)@!55U;H?A4``('&
MR($``%.#[$QEH10```")1"0\,<`QP,=$)!I?7T5.C5PD%,=$)!Y67U!!QT0D
M(E)?0TR+KO#___^-OG:@___'1"0F14%.7\=$)"I?("`@QT0D+B`@("#'1"0R
M("`@(,=$)#8@("`@9HE$)#J)VHGXZ)+T__^%P'0OBU0D%(M%`(T$D(M0!(D0
MA=)TX(UV`(M0"(/`!(D0A=)U](G:B?CH8_3__X7`==&+KO#___^-OG^@__^)
MVHGXZ$KT__^%P'0OBU0D%(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U
M](G:B?CH&_3__X7`==&+KO#___^-OH>@__^)VHGXZ`+T__^%P'0OBU0D%(M%
M`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CHT_/__X7`==&+KO#_
M__^-OI"@__^)VHGXZ+KS__^%P'0OBU0D%(M%`(T$D(M0!(D0A=)TX(UV`(M0
M"(/`!(D0A=)U](G:B?CHB_/__X7`==&-KI>@__^+OO#___^)+"2)VHGHZ&_S
M__^%P'0TBU0D%(L'C020BU`$B1"%TG3AC;0F`````&:0BU`(@\`$B1"%TG7T
MB=J)Z.@[\___A<!US(NN\/___XV^IZ#__XG:B?CH(O/__X7`="^+5"04BT4`
MC020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.CS\O__A<!UT8V&7*#_
M_XN^\/___XE$)`2)Q8G:B>CHU/+__X7`=#&+5"04BP>-!)"+4`2)$(72=.&-
MM@````"+4`B#P`2)$(72=?2)VHGHZ*/R__^%P'7/C:ZSH/__B[[P____B6PD
M#(G:B>CHAO+__X7`="N+5"04BP>-!)"+4`2)$(72=.&+4`B#P`2)$(72=?2)
MVHGHZ%OR__^%P'75C:Z]H/__B[[P____B6PD"(G:B>CH/O+__X7`=#.+5"04
MBP>-!)"+4`2)$(72=.&-M"8`````D(M0"(/`!(D0A=)U](G:B>CH"_+__X7`
M=<V+KO#___^-OL>@__^)VHGXZ/+Q__^%P'0OBU0D%(M%`(T$D(M0!(D0A=)T
MX(UV`(M0"(/`!(D0A=)U](G:B?CHP_'__X7`==&+KO#___^-OF6@__^)VHGX
MZ*KQ__^%P'0OBU0D%(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:
MB?CH>_'__X7`==&)VHV&T:#__^AJ\?__B<*%P'0)BT0D".BK]?__B=J-AN*@
M___H3O'__XG"A<!T"XV&]*#__^B-]?__B=J-AO^@___H,/'__XG"A<!T+(M$
M)`3H<?7__XL$)(V6*Z'__^AC]?__BT0D/&4K!10```!U28/$3%M>7UW#B=J-
MA@^A___H\?#__XG"A<!T"XM$)`SH,O7__^N_@7PD*U!!4E]UM8%\)"]#3$5!
M=:MF@7PD,TX]=:*-5"0UZ]+HV!$``(VT)@````"04^C*X___@<-J?0``@^P8
M9:$4````B40D#(N#^````(/X_W0<BU0D#&4K%10```!U0(/$&%O#C;0F````
M`(UV`(U4)`B-@[.@___H8?#__XG",<"%TG02#[8"/#`/E<*$P`^5P`^VP"'0
MB8/X````Z[/H6A$``(VT)@````"-=@!3Z$KC__^!P^I\``"#[`CH#-___X/L
M#%#HX][__X/$$(7`=`*+`(/$"%O#C70F`)!55U93Z!?C__^!P[=\``"#["QE
MH10```")1"0<,<"-5"08BWPD0(VK+:'__XGHZ,WO__^%P'0'@#@`B<9U(HM$
M)!QE*P44````#X6A````B?J#Q"R)Z%M>7UWI\?/__Y"#[`A74.C&WO__@\00
MA<!T'XM$)!QE*P44````=7*#Q"Q;7E]=PXVT)@````"-=@"#[`Q7Z!?>__^)
M-"2)1"0<Z`O>__^+5"0<C40"`HD$).B+WO__@\0,B<*-@W*@__]64(V#=:'_
M_U=0:O]J`5*)5"0LZ!C?__^#Q""+5"0,BT0D'&4K!10````/A&'____H*Q``
M`(VT)@````"-="8`4^@:XO__@<.Z>P``@^P4:F#H*M[__\<``2-%9\=`!(FK
MS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````"#
MQ!A;PXVT)@````"-M"8`````5U93Z+CA__^!PUA[``"#["QEH10```")1"0H
M,<"+="0\5NAI^/__@\00#[80B<>$TG06C70F`)"#P`&`^B]U`HG'#[80A-)U
M[XN#^````(7V#Y7!@_C_=&>%P`^5P"'!A,EU'(M$)!QE*P44````#X60````
M@\0@6UY?PXUT)@"`/@!TWX/L!(V#/:'__VH$4%?H&=[__X/$$(7`=<:+1"0<
M92L%%````'5:@\0@B?!;7E_I2.___XVT)@````"0C50D&(V#LZ#__XA,)`_H
MS>W__P^V3"0/A<!T"P^V`(3`=`0\,'4/QX/X`````````.EN____QX/X````
M`0```.E;____Z+8.``"-M@````!5,<E75E/HI>#__X'#17H``(/L'(ML)#"+
M5"0XBW0D-(T$U0`````#110/DL&)112)T(G/BTT8@_\!C7T<@]G_P>@=`<B)
M11B+15R%P`^%!0$``(/Z/P^.7`$``(U"P(E$)`S!Z`:-6`&)1"0(P>,&`?.-
MM@````"+!H/&0(D'BT;$B4<$BT;(B4<(BT;,B4<,BT;0B4<0BT;4B4<4BT;8
MB4<8BT;<B4<<BT;@B4<@BT;DB4<DBT;HB4<HBT;LB4<LBT;PB4<PBT;TB4<T
MBT;XB4<XBT;\B4<\B>CHT.#__SG>=92+1"0(BU0D#,'@!BG"@_H$<D*+`XE%
M'(M$$_R)1!?\C4<$@^#\*<<I^P'7@^?\@_\$<A*#Y_PQR8LT"XDT"(/!!#GY
M<O.)55R#Q!Q;7E]=PXUT)@"%TG3M#[8#B$4<]L("=.(/MT03_F:)1!?^Z]:-
M="8`D+E`````*<$YT7]-B50D.(/L!`'X48E,)!!64.BXVO__BTPD&(M%7(/$
M$(M4)#@!R(/X0(E%7'6<*<J)Z`'.B50D..@1X/__BU0D..FK_O__C;0F````
M`)")T>NOC70F`(GSZ3+___^05>BK#```@<6*>```5U93@^P<BUPD-(MT)#"+
M4Q2->QR)T,'J`P_(B40D#(M#&(/B/\9$$QR`#\B)1"0(C4(!C10'@_@X#X[M
M````N4`````IP70-,<#&!`(`@\`!.<AR]8G8Z(C?__^-5P3'0QP`````,<"#
MXOS'1S0`````*=>-3SB)U\'I`O.KBT0D"(E#5(M$)`R)0UB)V.A1W___BP.#
M[`S!Z!B(!HL#P>@0B$8!BP.(9@*+`XA&`P^V0P>(1@0/MT,&B$8%BT,$B&8&
MBT,$B$8'#[9#"XA&"`^W0PJ(1@F+0PB(9@J+0PB(1@L/MD,/B$8,#[=##HA&
M#8M##(AF#HM##(A&#P^V0Q.(1A`/MT,2B$81BT,0B&82BT,0B$834XGKZ,78
M__^#Q"Q;7E]=PXUT)@"0N3@````Q_RG!@_D$<CJ-0@3'`@````"#X/S'1`K\
M`````"G"`=&#X?R#^00/@B#___^#X?PQTHD\$(/"!#G*<O;I#/___V:0A<D/
MA`+____&`@#VP0(/A/;^__\QP&:)1`K^Z>K^__]55U93C80D`(#__X'L`!``
M`(,,)``YQ'7R@>P,`0``Z"S=__^!P\QV``"+A"0@@0``B40D$(U\)"R)^F6A
M%````(F$)/R````QP(V#5*'__\>$)*``````````B40D"(F$))@```"-@UJ@
M__^)A"2<````C8/MH/__B80DJ````(V#6:'__XF$)*P```"-@PJA__^)A"2P
M````C8-AH?__B80DM````(V#2*'__XE$)`R)A"2,````C8-EH?__B80DD```
M`(V#7*#__\>$)+@`````````QX0DE`````````")1"08Z$;I__^%P'0)@#@`
M#X5!!```Z"38__^#[`Q0Z/O7__^#Q!"%P`^$H`,``(LHA>T/A)8#``"#[`Q5
MZ+W7__^-1``!B00DZ$'8__^)1"0<#[9%`(/$$(3`=#F+="0,C8MNH?__B7PD
M%(GWB<Z#[`P/ML"#Q0%05FK_:@%7@\<"Z+C8__\/MD4`@\0@A,!UW8M\)!2-
MM"2D````C8/TH/__ZQ2-M"8`````C78`BT8$@\8$A<!T-HGZZ(_H__^)Q87`
M=.F`.`!TY.A/Z?__A<!TVX/L#%7HLMC__X/$$(G"A<!U2XVT)@````!FD(ML
M)`B-M"28````ZQ.-=@"+;@2%[70I@\8$@'T``'0@B>CH">G__X7`=.6#[`Q5
MZ&S8__^#Q!"%P'35B<+K`Y`QTH/L#%*)5"0DZ,'6__]9_W0D&(G&Z+76__^-
MK`8$!```B2PDZ#;7__^)1"08B<:-@SVA____="0<4(V#=*#__XE$)"10BU0D
M,(V#<Z'__U)0:O]J`5;HM-?__X/$*&C``0``5NC&U/__@\00@_C_=1#HF=3_
M_XL`@_@1#X6&`@``@^P(5_]T)!3H,=?__X/$$(G&A<!T4(/L#/]T)!2+1"0@
M_S"-@Q2B__]0,>V+@^S___]J`?\PZ-/4__^#Q""+A"3\@```92L%%`````^%
M/`4``('$#($``(GH6UY?7<.-M"8`````BT0D/"4`\```/0!```!UH(M$)$2)
M1"04Z`O6__\Y1"04=8V+1"0\)?\!```]P`$```^%>?___X/L#%7H.-;__XGZ
MB<6-@SBA___HZ>;__X/$$(7`#X0.`@``@^P,4.@5U___65I0BT0D'/\PZ'?N
M__^#Q!")P87`#X3J`0``@^P,48E,)"3H7=7__X/$$(M,)!2#^`.)PG8_@^P(
MC8-\H?__4(U$$?R)5"0HB4PD(%#HX];__X/$$(M,)!2%P'48BU0D'(/Z!`^$
M?@,``(!\$?LO#X1S`P``BX/X````@_C_#X0A`P``C9.SH/__B50D$(7`#X2$
M`0``BT0D$(V3*Z'__XV[M:'__^AZZO__Z"73__]74(V#E:'___]T)!3_="04
M4&K_:@%5Z/K5__^#Q""-@Z.A__^)1"00ZS2-=@#HX]+__X,X$74]Z.G2__^#
MQ@&#[`Q75E#_="0D_W0D)/]T)#!J_VH!5>BZU?__@\0P@^P(:,`!``!5Z,G2
M__^#Q!"#^/]TN8/L#/]T)!3HQ=/__XM$)"B)ZNCJZ?__B2PDZ)+U__^#Q!#I
M*O[__XVT)@````"-=@"+1"0,C;0DC````.L-C78`BT8$A<!T,(/&!(GZZ%_E
M__^%P'3K@#@`=.:#[`Q0Z(W5__^#Q!")Q87`#X4J_/__BT8$A<!UT(/L#(VK
M3:'__VH-Z&G4__^)1"0<@\00N%,```#I)OS__X/L"%#_="04BT0D(/\PC8/8
MH?__Z8K]__^-M"8`````@^P,4(E$)!CHZ_3__XM$)!B)!"3H']7__X/$$(G%
MZ77]__^-="8`D(M$)!"+".D+_O__QX/X`````````(/L"&H`4>@0TO__@\00
MB<>-@[.@__^)1"00A?\/A%K^__]J`FK_:NY7Z-W4__^#Q`QJ!HV$)`0!``")
M1"084%?H=M+__X/$$("\)/P`````=0Z`O"3]````0P^$S@$``&H`:@!J`%?H
MG]3__\<$)&````#H@]/__X/$$,<``2-%9XG&B6PD%(ML)!#'0`2)J\WOQT`(
M_MRZF,=`#'94,A#'0!#PX=+#QT`4`````,=`&`````#'0%P`````ZQ.-="8`
MD(/L!%!55NA=]O__@\00@^P$:`"```!55^C;T?__@\00A<!_W(ML)!2#[`Q7
MZ-?2__]86E:-M"3T````5NCG]___B?*-@VZA__^-M"3/````B?>#Q!");"04
MB<6)="0<B=:-M"8`````#[8&@^P,@\8!4%5J_VH!5X/'`NAHT___@\0@.W0D
M$'7?BVPD%(MT)!R-@[6A___&A"3G`````%"-@X:A__]6_W0D%/]T)!10:O]J
M`57H+M/__X/$(.F%_?__C;8`````C8.SH/__B?J)3"04B40D$.@;X___BTPD
M%(7`#X1*_O__#[8`A,`/A#_^__\\,`^$-_[__\>#^`````$```#IKOS__XM$
M)!"+4`2%T@^$?OS__XE,)!"#[`Q2B50D).A]T?__@\00BTPD$(/X`P^&7?S_
M_X/L"(V+@:'__U&+5"0@C40"_%#H!=/__X/$$(M,)!"%P`^%-OS__XM,)!3I
M+?S__X"\)/X```!!#X4D_O__@+PD_P```$,/A1;^__^`O"0``0``2`^%"/[_
M_X"\)`$!``!%#X7Z_?__:@)J_VK&5^B9TO__@\0,:BF+="085E?H.=#__XV#
MM:'__U"-@X:A__]6_W0D)/]T)"10:O]J`57H"-+__X/$,.E?_/__Z"L#``"-
MM"8`````C70F`%575E/H%]7__X'#MVX``(/L.&6A%````(E$)"@QP(NST/__
M__\VZ,7/__]9_S:)Q^B[S___#[979(U\)"B(4&6)^HV#EZ#__^BSX?__@\00
MA<!T"8`X,0^$FP$``.B.[/__@^P,_S;HA,___XV3M*'__VH#:@%24.A#S___
M@\0@B<6%P'0ZBT`,@^P,BQ")5"08_S;H5\___X/$#(V+MJ'__U&+5"044E#H
M(L___XM%#(/$$(LH]D4*0`^%@`$``(/L#/\VZ";/__^-D[NA__]J`VH!4E#H
MY<[__X/$((7`B40D#'1!B?J-@V6@___H#>'__XM,)`R)Q8L&BU$,A>T/A`H!
M``"+$H/L#(E4)!A0Z-O.__^#Q`Q5BU0D%%)0Z*S.__^#Q!"#[`S_-NB_SO__
M@\0,C9.]H?__:@%24.CMS?__B<58_S;HH\[__X/$#(V3TJ'__U)54.ARSO__
M6O\VZ(K.__^)^L9`90"-@UR@___HB>#__X/$$(F#*`$``(G&A<!T0H/L"&C`
M`0``5NA\S?__@\00C5`!@_H!=@F#^!$/A;,```"+1"0<92L%%`````^%N```
M`(/$+%M>7UW#C;0F`````(/L#/^S+`$``.CZ]?__@\00B8,H`0``B<:%P'6A
M@^P,C8-HHO__4.C<S___C70F`(!X`0`/A&#^___I5O[__XVT)@````!FD(N+
M+`$``(/L#(LIBPJ)3"084.C)S?__BT0D'(GJZ#[C__^#Q!#I[?[__XVV````
M`(/L#/\VZ*;-__]96E50Z`W/__^#Q!#I9?[__U"+@RP!``!6_S"-@XRB__]0
MZ%_/___HJ@```(LT),-FD&:09I!5Z%L```"!Q3IL``!75E.#[`R)ZXM\)"CH
M(\S__XV=O/[__XV%N/[__RG#P?L"="4Q]HVV`````(/L!%?_="0L_W0D+/^4
MM;C^__^#Q@&#Q!`Y\W7C@\0,6UY?7<.-=@##BRPDPV:09I!FD&:09I"04^@J
MTO__@</*:P``@^P(_[/T````_W0D'/]T)!S_="0<Z(K,__^#Q!A;PV:09I"0
M4^CZT?__@<.::P``@^P(Z#S.__]3@^P(Z./1__^!PX-K``"#Q`A;PP``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!
M4EE?4$%42`!P87(M`"UE`"TM`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!4
M35``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4R`"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*
M<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P
M+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@
M,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M
M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'
M>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G
M;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M
M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,[
M"FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*
M?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2![
M"B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S
M(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^
M/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U
M9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@
M)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC
M7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE
M.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@
M/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L
M(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S
M="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F
M=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@
M)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;
M(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B
M.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%
M3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@+3$X
M+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D8G5F
M+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L
M"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I
M9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E
M("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``'!E<FQX<VDN8P````$;`SL0
M`0``(0```,2!__]8`0``9(7__WP!``!TA?__O`@``,2'__\L`0``!(G__Y`!
M``#DE/__U`$``+25__],`@``1);__Y@"``#4E___6`,``%28__^T`P``-)G_
M_U0$``!TF___U`0``+2;__\$!0``A)S__YP%``"4G/__L`4``*2>__^<!@``
MU)[__[`&``#4G___)`<``#2D__]D!P``M*3__X@'``#DI/__M`<``.2E__\X
M"```1*;__UP(``!4I___!`D``!2I__]4"0``M*K__Z0)``#DLO__<`T``%JU
M__^(#@``9+7__YP.``#$M?__Z`X``,6U___\#@``U+7__Q`/```$MO__/`\`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````D(;__S8`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!D@/__H`,````."$8.
M#$H/"W0$>``_&CLJ,B0B$````$````#@@___"`````````!`````5````&R'
M___4"P```$$."(4"00X,AP-!#A"&!$$.%(,%2`Z0`P.^"PH.%$'##A!!Q@X,
M0<<."$'%#@1!"P```'0```"8````")/__\P`````00X(A0)!#@R'`T$.$(8$
M00X4@P5.#C`"00XT00XX1`X\00Y`2`XP6`H.%$/##A!!Q@X,0<<."$'%#@1!
M"W8*#A1#PPX00<8.#$''#@A!Q0X$1`M##A1#PPX00\8.#$''#@A!Q0X$`$@`
M```0`0``8)/__X(`````00X(A@)##@R#`TX.B`%1#HP!00Z0`4@.@`%A#H@!
M0@Z,`4$.D`%(#H`!8@H.#$'##@A!Q@X$00L```"\````7`$``*23__^.`0``
M`$$."(4"00X,AP-!#A"&!$,.%(,%40Z@`6P*#A1!PPX00<8.#$''#@A!Q0X$
M20M##JP!00ZP`4@.H`%;#JP!00ZP`4@.H`%Q#JP!00ZP`68.K`%!#J@!10ZL
M`4$.L`%$#K0!0@ZX`4(.O`%!#L`!2`ZH`40.K`%!#K`!2`Z@`5@.K`%!#K`!
M2`Z@`4,.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`4T.K`%!#K`!4`Z@`0!8````
M'`(``'24__]Q`````$$."(8"00X,@P-.#AQ(#B!&#AQ"#B!,#B1,#BA!#BQ!
M#C!(#AQ"#B!&#AQ!#AA"#AQ)#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!)P`
M``!X`@``F)3__]D`````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@1P[$(&4.
MR"!+#LP@00[0($@.P"!5#L0@00[(($(.S"!!#M`@2`[`($T.S"!"#M`@1@[4
M($$.V"!!#MP@00[@($@.P"!.#LP@0@[0($@.Q"!$#L@@00[,($$.T"!(#L`@
M5@H.%$'##A!!Q@X,0<<."$'%#@1%"P!\````&`,``-B4__\X`@```$$."(4"
M0PX,AP-!#A"&!$,.%(,%3@Y,5PY02`Y`6@Y,0PY02`Y``E(.3$L.4$@.0`)D
M"@X40<,.$$'&#@Q!QPX(0<4.!$D+`F0.3$$.4%(.0%0.1$4.2$4.3$$.4%0.
M0%D.2$$.3$$.4$X.0````"P```"8`P``F);__SL`````00X(@P).#AQ(#B!,
M#B1,#BA!#BQ!#C!(#@A!PPX$`)0```#(`P``J);__\@`````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#I0@2@Z40$<.L$!D#KA`1PZ\0$$.P$!'#L1`10[(0$(.
MS$!(#M!`2`ZT0$4.N$!%#KQ`00[`0$@.L$!'#KQ`1@[`0$@.L$!)#K1`00ZX
M0$$.O$!!#L!`30ZP0%8*#A1#PPX00<8.#$''#@A!Q0X$00L`$````&`$``#@
MEO__!0````````#H````=`0``-R6__\%`@```$$."(4"00X,AP-!#A"&!$$.
M%(,%1@Z4($H.L"$"0`ZX(4(.O"%##L`A2`ZP(6T*#A1!PPX00<8.#$''#@A!
MQ0X$1@M##KPA00[`(48.O"%!#K@A3PZ\(4$.P"%(#K`A=0ZX(4$.O"%!#L`A
M2`ZP(4L.O"%!#L`A2`ZP(6H.M"%*#K@A1`Z\(4$.P"%!#L0A10[((4(.S"%(
M#M`A2`ZX(40.O"%!#L`A2`ZP(5<.N"%!#KPA0@[`(4@.L"$"10ZX(4(.O"%!
M#L`A2`ZP(50.O"%!#L`A2`ZP(0```!````!@!0```)C__R0`````````<```
M`'0%```<F/__]0````!!#@B&`D$.#(,#3@X06`X<00X@2`X0`D,.'$<.($@.
M$$,*#@Q%PPX(0<8.!$0+8PX400X800X<1PX@2`X010H.#$/##@A!Q@X$0PM#
M#AQ'#B!(#A!#"@X,1<,."$'&#@1!"P`\````Z`4``*B8__]8!````$$."(4"
M00X,AP-!#A"&!$P.%(,%0PY@`_L#"@X40<,.$$'&#@Q!QPX(0<4.!$$+(```
M`"@&``#(G/__=@````!!#@B#`DX.(&4*#@A!PPX$2PL`*````$P&```DG?__
M*P````!!#@B#`DX.$$@.'$$.($@.$$D."$'##@0```"`````>`8``"B=___U
M`````$$."(4"00X,AP-!#A"&!$$.%(,%3@Y``D(*#A1#PPX00<8.#$''#@A!
MQ0X$1@M##DA!#DQ!#E!(#D!4"@X40<,.$$'&#@Q!QPX(0<4.!$L+0PY,00Y0
M9`Y$20Y(00Y,1PY000Y40@Y80@Y<00Y@3`Y````@````_`8``*2=__]2````
M`$$."(,"3@X<0@X@?PX(0<,.!`!<````(`<``."=__\*`0```$$."(<"00X,
MA@-!#A"#!$X./%$.0$@.,`)."@X00<,.#$'&#@A!QPX$10M(#C1(#CA!#CQ!
M#D!(#C!4"@X00\,.#$'&#@A!QPX$30L```!$````@`<``+!\__](`@```$0,
M`0!)$`4"=0!!$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-[`0K!#`$`0<-!QD''
M0<5##`0$00M,````R`<``$B>__^_`0```$$."(4"0PX,AP-!#A"&!$$.%(,%
M3@XP`QL!"@X40<,.$$'&#@Q!QPX(0<4.!$4+<@XT0PXX10X\00Y`3PXP`$P`
M```8"```N)___Z`!````00X(A0),#@R'`T$.$(8$00X4@P5##C`"D@X\`H`.
M0$H.%$'##A!!Q@X,0<<."$'%#@1&#C"#!84"A@2'`P``R`,``&@(```(H?__
M)0@```!!#@B%`D$.#(<#00X0A@1!#A2#!4<,`)2``DX-!$8.H(("`N`.K(("
M00ZP@@)(#J""`E4.K(("00ZP@@)<#J""`ED.K(("1PZP@@)!#K2"`D(.N(("
M0@Z\@@)!#L""`D\.H(("`DD.K(("00ZP@@)(#J""`GT.K(("00ZP@@)(#J""
M`DX.K(("00ZP@@)*#JR"`D0.L(("9@ZT@@)!#KB"`DL.O(("2P[`@@)!#L2"
M`D(.R(("0@[,@@)!#M""`D@.J(("10ZL@@)!#K""`D@.H(("6`ZH@@)!#JR"
M`D0.L(("2`Z@@@))#JR"`D0.L(("1@ZT@@)'#KB"`DH.O(("0@[`@@)(#J""
M`EH*#A1#PPX00<8.#$''#@A!Q0X$2`MZ#JR"`D$.L(("5PZ@@@)+#JR"`D$.
ML(("1@ZL@@)!#JB"`D$.K(("1@ZP@@)(#J""`DT.K(("00ZP@@),#J""`DX.
MJ(("1PZL@@)-#K""`D@.H(("`EP.I(("00ZH@@)*#JR"`D0.L(("00ZT@@)"
M#KB"`D(.O(("00[`@@)(#J""`F0.K(("00ZP@@)!#K2"`D$.N(("1`Z\@@)$
M#L""`D0.Q(("0@[(@@)"#LR"`D$.T(("2`Z@@@)##JB"`D4.K(("00ZP@@)(
M#J""`D@.K(("1`ZP@@);#J""`GP.K(("00ZP@@)(#J""`E0.K(("2`ZP@@),
M#J""`DT*#JB"`D$.K(("1`ZP@@)&#K2"`E(+0PZL@@)!#K""`E@.H(("9`ZH
M@@)"#JR"`D$.L(("2`Z@@@)6#J2"`D(.J(("0@ZL@@)!#K""`D@.I(("0@ZH
M@@),#JR"`D$.L(("2`Z@@@):#J2"`D(.J(("0@ZL@@)!#K""`E0.H(("`DL.
MI(("00ZH@@)!#JR"`D$.L(("2`Z@@@)##J2"`D4.J(("00ZL@@)!#K""`D@.
MH(("2PZL@@)!#K""`D8.K(("00ZH@@)!#JR"`D@.L(("60Z@@@)9#JR"`D0.
ML(("00ZT@@)"#KB"`D(.O(("00[`@@)+#J""`ET.I(("1PZH@@)$#JR"`D0.
ML(("00ZT@@)"#KB"`D(.O(("00[`@@)(#J""`@)D#JR"`D$.L(("3`Z@@@)0
M#JB"`D<.K(("20ZP@@)(#J""`@)/#J2"`D(.J(("0@ZL@@)!#K""`D@.I(("
M0@ZH@@)%#JR"`D$.L(("3`ZT@@)'#KB"`D0.O(("1`[`@@)!#L2"`D(.R(("
M0@[,@@)!#M""`D@.H(("%`$``#0,``!LI?__=@(```!!#@B%`D$.#(<#00X0
MA@1!#A2#!4X.3%0.4$8.3$(.4&(.0%4.3$(.4$T.5$(.6$$.7$$.8$@.0$P.
M3$@.4$@.1$<.2$4.3$$.4$L.0$\.3$(.4$T.5$(.6$$.7$$.8$@.0&T.3$4.
M4$@.1$$.2$4.3$$.4$@.0$,.3$(.4$@.1$@.2$$.3$$.4$@.3$(.4$@.1$<.
M2$$.3$$.4$8.3$(.4%D.0$\.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!
MQ0X$2`M#"@Y,1@Y02`Y`3PY,1PY020MA#DQ)#E!3#D!.#DQ"#E!&#DQ!#DA!
M#DQ!#E!(#D!&"@Y$1PY(0@Y,1PY010L``!````!,#0``RJ;__P0`````````
M2````&`-``#`IO__70````!!#@B%`DP.#(<#00X0A@1!#A2#!4,.(&D.)$$.
M*$0.+$0.,$T.($<.%$'##A!!Q@X,0<<."$'%#@0``!````"L#0``U*;__P$`
M````````$````,`-``#!IO__!``````````H````U`T``+RF__\K`````$$.
M"(,"3@X01@X41`X81`X<1`X@2`X(0<,.!!@`````#@``P*;__Q0`````00X(
M@P).#A``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%`G
M````)P```0````L#```!````%@,```$````F`P``'0```,<$```,`````"``
M``T```!T5```&0```+B^```;````!````!H```"\O@``'`````0````$````
M-`(``/7^_V],!0``!0```&`,```&````,`8```H```#Z!```"P```!`````5
M``````````,`````P````@```,@!```4````$0```!<```!0$P``$0```-`2
M```2````@````!,````(````^___;P````C^__]O(!(``/___V\"````\/__
M;UH1``#Z__]O!0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-`C``#`O@`````````````V(```1B```%8@``!F(```=B```(8@
M``"6(```IB```+8@``#&(```UB```.8@``#V(```!B$``!8A```F(0``-B$`
M`$8A``!6(0``9B$``'8A``"&(0``EB$``*8A``"V(0``QB$``-8A``#F(0``
M]B$```8B```6(@``)B(``#8B``!&(@``5B(``&8B``!V(@``AB(``)8B``"F
M(@``MB(``,8B``#6(@``YB(``/8B```&(P``%B,``"8C```V(P``1B,``%8C
M``!F(P``=B,``(8C``"6(P``IB,``+8C````````],```/_____08@``1T-#
M.B`H4U5312!,:6YU>"D@,3$N,2XQ(#(P,C$P-3$P(%MR979I<VEO;B`R,S@U
M-6$Q-S8V,#EF93AD9&$V86)A9C)B,C$X-#9B-#4Q-SDV-F5B70``+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+F=N=2YP<F]P
M97)T>0`N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M```````````````````````````````````````+`````0````(```"T`0``
MM`$``!,```````````````$`````````$P````<````"````R`$``,@!```D
M```````````````$`````````"8````'`````@```.P!``#L`0``*```````
M````````!``````````Y````!P````(````4`@``%`(``"``````````````
M``0`````````2P````4````"````-`(``#0"```8`P``!P`````````$````
M!````$<```#V__]O`@```$P%``!,!0``Y`````<`````````!`````0```!1
M````"P````(````P!@``,`8``#`&```(`````0````0````0````60````,`
M```"````8`P``&`,``#Z!``````````````!`````````&$```#___]O`@``
M`%H1``!:$0``Q@````<``````````@````(```!N````_O__;P(````@$@``
M(!(``+`````(`````@````0`````````?0````D````"````T!(``-`2``"`
M````!P`````````$````"````(8````)````0@```%`3``!0$P``R`$```<`
M```9````!`````@```"/`````0````8`````(````"```"``````````````
M``0`````````B@````$````&````("```"`@``"@`P`````````````0````
M!````)4````!````!@```,`C``#`(P``"```````````````"`````@```">
M`````0````8```#0(P``T",``*0P`````````````!``````````I`````$`
M```&````=%0``'14```4```````````````$`````````*H````!`````@``
M``!@````8```6CX`````````````!`````````"R`````0````(```!<G@``
M7)X``!0!``````````````0`````````P`````$````"````<)\``'"?``!(
M#@`````````````$`````````,H````.`````P```+B^``"XK@``!```````
M````````!`````0```#6````#P````,```"\O@``O*X```0`````````````
M``0````$````X@````8````#````P+X``,"N```0`0``"``````````$````
M"````)D````!`````P```-"_``#0KP``,```````````````!`````0```#K
M`````0````,`````P````+```/````````````````0````$````]`````$`
M```#````\,```/"P```0```````````````$`````````/H````(`````P``
M``#!````L0``0!``````````````(`````````#_`````0```#``````````
M`+$``%8```````````````$````!`````0````,``````````````%:Q```(
3`0`````````````!````````````
